function art_network = ART_Create_Network(numFeatures)
% Creates a new network, with a specified number of features. 
% The network is created to expand the number of categories as needed.
% In this way, the ART network can grow to encompass new data according to
% the vigilance parameter, which defaults to 0.75. THe initial number of
% categories is set to 1. THe maximum number of categories defaults to 100.
% THe bias defaults to 0.000001, thenumber of epochs default to 100, and
% the learning-rate defaults to 1.0, i.e. fast learning.

% THe input parameter numFeatures is the number of features the network
% expects of the input data. THe value must be positive, and an integer.
% THe return parameters:
% THe ART_NETWORK is the structure that holds all of the information for
% the network. It must be passed both into ART_LEARN()and ART_CATEGORIZE.
% THer fields of this stucture are numFeatures, numCategories,
% maxNumCategories, weigth,vigilance, bias, numEpochs and learning rate.

% MAkes sure the user specifies the required parameter. 

if (nargin ~= 1)
    error('You must specify a number of features');
end

%Check the range of input parameters
numFeatures = round(numFeatures);
if (numFeatures < 1)
    error('The number of features must be a positive integer');
end

%Create and initialize the weigth matrix
weigth=ones(numFeatures, 0);

%create the structure and return

art_network=struct('numFeatures', (numFeatures), 'numCategories',....
{0}, 'maxNumCategories', {100}, 'weigth', {weigth}, 'vigilance',{0.75},....
'bias', {0.000001}, 'numEpochs',{100},'learninRate',{1.0});
return


